% This script uses Gaussian elimination to solve the interpolation problem by directly
% solving the linear system Ax = b, where A is the Vandermonde matrix and b is the vector of
% function evluations. The computations are performed on uniform grid of the unit interval.

% Set the different numbers of interpolation points:
narray = [5 10 20 50 80 100];
% Define a fine grid to plot the result:
xplot = 0:1/199:1;

% Loop over all the step sizes:
for j = 1:length(narray)
    % Define the step size:
    n = narray(j);
    h = 1/n;
    % Define the grid:
    x = 0:h:1;
    % Evaluate the function:
    b = x.^4 - x.^2;
    % Set up the Vandermonde matrix:
    A = zeros(n+1,n+1);
    for k =0:n
        A(k+1,:) = x(k+1).^[0:n];
    end
    % Solve the linear system:
    LR= LRDecomp(A);
    a = SolveLR(b, LR);
    n
    disp 'The solution vector'
    a
    % Evaluate the interpolation polynomial:
    ypoly = zeros(n+1,200);
    for m = 0:n
        ypoly(m+1,:) = xplot.^m;
    end
    yplot = a'*ypoly;
    % Make the plot:
    figure()
    hold all
    plot(xplot,yplot)
    plot(x,b)
end